@@ -14,20 +14,21 @@
 #include "isotope.h"
 
 
-int set_element(Element* element, Isotope* isotopes, char* name, int amount, int iso_amount)
+int set_element(Element* element, Isotope* isotopes, char* name, size_t amount, unsigned short iso_amount)
 {
     element->amount = amount;
     element->iso_amount = iso_amount;
     strcpy(element->name, name);
-    memcpy(element->isotopes, isotopes, iso_amount*sizeof(Isotope));
+    memmove(element->isotopes, isotopes, iso_amount*sizeof(Isotope));
+    
     qsort(element->isotopes, iso_amount, sizeof(Isotope), isotope_sort_by_abundance);
 	return 0;
 }
 
 int elements_sort_by_isoamount_inc(const void *a, const void *b)
 {
-    double y1 = ((const struct Element*)a)->iso_amount;
-    double y2 = ((const struct Element*)b)->iso_amount;
+    unsigned short y1 = ((const struct Element*)a)->iso_amount;
+    unsigned short y2 = ((const struct Element*)b)->iso_amount;
     
     if (y1 > y2) {
         return 1;
@@ -39,8 +40,8 @@ int elements_sort_by_isoamount_inc(const void *a, const void *b)
 
 int elements_sort_by_isoamount_dec(const void *a, const void *b)
 {
-    double y1 = ((const struct Element*)a)->iso_amount;
-    double y2 = ((const struct Element*)b)->iso_amount;
+    unsigned short y1 = ((const struct Element*)a)->iso_amount;
+    unsigned short y2 = ((const struct Element*)b)->iso_amount;
     
     if (y1 < y2) {
         return 1;
